var searchData=
[
  ['page_0',['API Reference Start Page',['../index.html',1,'']]],
  ['panel_20container_1',['Panel (container)',['../_overlay-_scripts.html#Panel',1,'']]],
  ['param_5findexed_2',['param_indexed',['../_high-level-_programs.html#autotoc_md194',1,'']]],
  ['param_5findexed_5fauto_3',['param_indexed_auto',['../_high-level-_programs.html#autotoc_md195',1,'']]],
  ['param_5fnamed_4',['param_named',['../_high-level-_programs.html#autotoc_md196',1,'']]],
  ['param_5fnamed_5fauto_5',['param_named_auto',['../_high-level-_programs.html#autotoc_md197',1,'']]],
  ['parameter_20specification_6',['Parameter specification',['../_high-level-_programs.html#Program-Parameter-Specification',1,'']]],
  ['parameters_7',['Parameters',['../_high-level-_programs.html#Declaring-Shared-Parameters',1,'Declaring Shared Parameters'],['../_high-level-_programs.html#Default-Program-Parameters',1,'Default Program Parameters']]],
  ['parameters_8',['parameters',['../_material-_scripts.html#autotoc_md178',1,'Available parameters'],['../_what_is_instancing.html#InstancingCustomParameters',1,'Custom parameters'],['../_hardware-_buffers.html#autotoc_md241',1,'Lock parameters'],['../_high-level-_programs.html#Matrix-parameters',1,'Matrix parameters']]],
  ['paramspanel_9',['ParamsPanel',['../trays.html#autotoc_md323',1,'']]],
  ['particle_20affectors_10',['Particle Affectors',['../_particle-_scripts.html#Particle-Affectors',1,'Particle Affectors'],['../_particle-_scripts.html#Standard-Particle-Affectors',1,'Standard Particle Affectors']]],
  ['particle_20emitters_11',['Particle Emitters',['../_particle-_scripts.html#Particle-Emitters',1,'Particle Emitters'],['../_particle-_scripts.html#Standard-Particle-Emitters',1,'Standard Particle Emitters']]],
  ['particle_20scripts_12',['Particle Scripts',['../_particle-_scripts.html',1,'Scripts']]],
  ['particle_20system_20attributes_13',['Particle System Attributes',['../_particle-_scripts.html#Particle-System-Attributes',1,'']]],
  ['particle_5fheight_14',['particle_height',['../_particle-_scripts.html#autotoc_md209',1,'']]],
  ['particle_5fwidth_15',['particle_width',['../_particle-_scripts.html#autotoc_md208',1,'']]],
  ['pass_16',['Using GPU Programs in a Pass',['../_material-_scripts.html#Using-Vertex_002fGeometry_002fFragment-Programs-in-a-Pass',1,'']]],
  ['pass_20classification_20and_20vertex_20programs_17',['Pass Classification and Vertex Programs',['../_shadows.html#Pass-Classification-and-Vertex-Programs',1,'']]],
  ['pass_20properties_18',['RTSS Pass properties',['../rtss.html#rtss_custom_mat',1,'']]],
  ['pass_5fop_19',['pass_op',['../_compositor-_scripts.html#autotoc_md94',1,'']]],
  ['passes_20',['Passes',['../_shadows.html#Manually-Categorising-Illumination-Passes',1,'Manually Categorising Illumination Passes'],['../_compositor-_scripts.html#Compositor-Passes',1,'Passes'],['../_material-_scripts.html#Passes',1,'Passes']]],
  ['passes_20to_20copied_20materials_21',['Adding new Techniques, Passes, to copied materials',['../_material-_scripts.html#Adding-new-Techniques_002c-Passes_002c-to-copied-materials_003a',1,'']]],
  ['per_20batch_22',['Instances per batch',['../_what_is_instancing.html#InstancesPerBatch',1,'']]],
  ['per_20track_23',['Subtype applies per track',['../_animation.html#autotoc_md55',1,'']]],
  ['percentage_20closest_20filtering_24',['Percentage Closest Filtering',['../_shadow_mapping_ogre.html#sm_pcm',1,'']]],
  ['performance_20and_20accuracy_25',['Performance and Accuracy',['../profiler.html#profAccuracy',1,'']]],
  ['performed_20by_20ogre_26',['Stencil optimisations performed by Ogre',['../_shadows.html#autotoc_md41',1,'']]],
  ['perspective_20aliasing_27',['Projective versus Perspective Aliasing',['../_shadow_mapping_ogre.html#sm_proj_aliasing',1,'']]],
  ['pixel_20boxes_28',['Pixel boxes',['../_hardware-_buffers.html#Pixel-boxes',1,'']]],
  ['pixel_20buffers_29',['Pixel Buffers',['../_hardware-_buffers.html#Hardware-Pixel-Buffers',1,'Hardware Pixel Buffers'],['../_hardware-_buffers.html#Updating-Pixel-Buffers',1,'Updating Pixel Buffers']]],
  ['pixel_20formats_30',['Pixel Formats',['../_hardware-_buffers.html#Pixel-Formats',1,'']]],
  ['pixelbuffer_31',['Getting a PixelBuffer',['../_hardware-_buffers.html#Getting-a-PixelBuffer',1,'']]],
  ['plane_20positioning_32',['Camera far plane positioning',['../_shadows.html#autotoc_md37',1,'']]],
  ['platform_20macros_33',['Cross-platform macros',['../_cross-platform-_shaders.html#OgreUnifiedShader',1,'']]],
  ['platform_20shaders_34',['Cross-platform Shaders',['../_cross-platform-_shaders.html',1,'manual']]],
  ['playing_20with_20projection_20matrices_35',['Playing with Projection Matrices',['../_shadow_mapping_ogre.html#sect_planeopt',1,'']]],
  ['plugins_36',['Plugins',['../tut__first_scene.html#TheOgreEnvironment',1,'']]],
  ['plugins_20cfg_37',['plugins.cfg',['../setup.html#autotoc_md308',1,'']]],
  ['point_38',['Entry Point',['../_high-level-_programs.html#autotoc_md189',1,'']]],
  ['point_20emitter_39',['Point Emitter',['../_particle-_scripts.html#Point-Emitter',1,'']]],
  ['point_20lights_40',['Point Lights',['../_shadows.html#autotoc_md44',1,'']]],
  ['point_5frendering_41',['point_rendering',['../_particle-_scripts.html#autotoc_md221',1,'']]],
  ['point_5fsize_42',['point_size',['../_material-_scripts.html#autotoc_md150',1,'']]],
  ['point_5fsize_5fattenuation_43',['point_size_attenuation',['../_material-_scripts.html#autotoc_md152',1,'']]],
  ['point_5fsize_5fmax_44',['point_size_max',['../_material-_scripts.html#autotoc_md154',1,'']]],
  ['point_5fsize_5fmin_45',['point_size_min',['../_material-_scripts.html#autotoc_md153',1,'']]],
  ['point_5fsprites_46',['point_sprites',['../_material-_scripts.html#autotoc_md151',1,'']]],
  ['polygon_5fmode_47',['polygon_mode',['../_material-_scripts.html#autotoc_md144',1,'']]],
  ['polygon_5fmode_5foverrideable_48',['polygon_mode_overrideable',['../_material-_scripts.html#autotoc_md145',1,'']]],
  ['portals_49',['CREATING PORTALS',['../dir_67ea8a25251f25c005532ef7e5f68f3d.html#autotoc_md4',1,'']]],
  ['pose_20animation_50',['Pose Animation',['../_animation.html#Pose-Animation',1,'']]],
  ['pose_20animation_20in_20vertex_20programs_51',['Pose Animation in Vertex Programs',['../_high-level-_programs.html#Pose-Animation-in-Vertex-Programs',1,'']]],
  ['position_52',['position',['../_particle-_scripts.html#autotoc_md231',1,'']]],
  ['positioning_53',['Camera far plane positioning',['../_shadows.html#autotoc_md37',1,'']]],
  ['post_20processing_54',['Post Processing',['../deferred.html#post',1,'']]],
  ['practical_20buffer_20tips_55',['Practical Buffer Tips',['../_hardware-_buffers.html#Practical-Buffer-Tips',1,'']]],
  ['precision_20aliasing_56',['Sampling Aliasing versus Depth Precision Aliasing',['../_shadow_mapping_ogre.html#sm_aliasing',1,'']]],
  ['prepare_20ambient_20colour_20and_20rebuild_20original_20depth_20buffer_57',['Prepare ambient colour and rebuild original depth buffer',['../deferred.html#autotoc_md284',1,'']]],
  ['preparing_20the_20build_20environment_58',['Preparing the build environment',['../building-ogre.html#autotoc_md260',1,'']]],
  ['preparing_20the_20objects_20for_20g_20buffer_20rendering_59',['Preparing the objects for G-Buffer rendering',['../deferred.html#autotoc_md276',1,'']]],
  ['preprocessor_20definitions_60',['Preprocessor definitions',['../_high-level-_programs.html#Preprocessor-definitions',1,'']]],
  ['prevention_3a_20avoiding_20fragmentation_61',['Prevention: Avoiding fragmentation',['../_what_is_instancing.html#InstancingDefragmentingBatchesPrevention',1,'']]],
  ['process_62',['Simplified Diagram of Process',['../_external-_texture-_sources.html#autotoc_md297',1,'']]],
  ['process_63',['Overriding the automatic process',['../deferred.html#autotoc_md281',1,'']]],
  ['processing_64',['Post Processing',['../deferred.html#post',1,'']]],
  ['profile_20glsl_20features_65',['Compatibility profile GLSL features',['../_high-level-_programs.html#Legacy-GLSL-features',1,'']]],
  ['profiler_66',['Profiler',['../profiler.html#autotoc_md302',1,'Disabling the Profiler'],['../profiler.html',1,'Using the Profiler']]],
  ['profiles_67',['Disabling Individual Profiles',['../profiler.html#autotoc_md303',1,'']]],
  ['program_20parameters_68',['Default Program Parameters',['../_high-level-_programs.html#Default-Program-Parameters',1,'']]],
  ['program_20scripts_69',['GPU Program Scripts',['../_high-level-_programs.html',1,'Scripts']]],
  ['programmatic_20creation_70',['Programmatic creation',['../_compositor-_scripts.html#Compositor-API',1,'Programmatic creation'],['../_high-level-_programs.html#GpuProgram-API',1,'Programmatic creation']]],
  ['programmatically_71',['Setting properties programmatically',['../rtss.html#RTSS-Props-API',1,'']]],
  ['programmers_72',['programmers',['../meshlod-generator.html#meshlod-nonprog',1,'How to use it for non-programmers'],['../meshlod-generator.html#meshlod-prog',1,'How to use it for programmers']]],
  ['programs_73',['Programs',['../_high-level-_programs.html#autotoc_md188',1,'High Level Programs'],['../_high-level-_programs.html#Instancing-in-Vertex-Programs',1,'Instancing in Vertex Programs'],['../_high-level-_programs.html#Morph-Animation-in-Vertex-Programs',1,'Morph Animation in Vertex Programs'],['../_high-level-_programs.html#multi-language-programs',1,'Multi-language Programs'],['../_shadows.html#Pass-Classification-and-Vertex-Programs',1,'Pass Classification and Vertex Programs'],['../_high-level-_programs.html#Pose-Animation-in-Vertex-Programs',1,'Pose Animation in Vertex Programs'],['../_high-level-_programs.html#Shadows-and-Vertex-Programs',1,'Shadows and Vertex Programs'],['../_high-level-_programs.html#Skeletal-Animation-in-Vertex-Programs',1,'Skeletal Animation in Vertex Programs'],['../_high-level-_programs.html#Unified-High_002dlevel-Programs',1,'Unified High-level Programs']]],
  ['programs_74',['programs',['../_high-level-_programs.html#Cg',1,'Cg programs'],['../_high-level-_programs.html#GLSL',1,'GLSL programs'],['../_shadows.html#texture_shadows_and_shaders',1,'Texture shadows and vertex / fragment programs']]],
  ['programs_20in_20a_20pass_75',['Using GPU Programs in a Pass',['../_material-_scripts.html#Using-Vertex_002fGeometry_002fFragment-Programs-in-a-Pass',1,'']]],
  ['progressbar_76',['ProgressBar',['../trays.html#autotoc_md326',1,'']]],
  ['project_77',['Setting up an OGRE project',['../setup.html',1,'tutorials']]],
  ['projection_20matrices_78',['Playing with Projection Matrices',['../_shadow_mapping_ogre.html#sect_planeopt',1,'']]],
  ['projective_20versus_20perspective_20aliasing_79',['Projective versus Perspective Aliasing',['../_shadow_mapping_ogre.html#sm_proj_aliasing',1,'']]],
  ['projects_80',['Integration in real projects',['../deferred.html#realprojects',1,'']]],
  ['properties_81',['properties',['../rtss.html#rtss_custom_mat',1,'RTSS Pass properties'],['../rtss.html#rtss_tu_props',1,'RTSS Texture Unit properties']]],
  ['properties_20programmatically_82',['Setting properties programmatically',['../rtss.html#RTSS-Props-API',1,'']]],
  ['putting_20it_20all_20together_83',['Putting it all together',['../deferred.html#autotoc_md280',1,'Putting it all together'],['../deferred.html#autotoc_md287',1,'Putting it all together']]],
  ['python_84',['Working with Python',['../working-with-numpy.html',1,'tutorials']]]
];
